@@ -64,7 +64,7 @@ void command_open(gpointer callback_data,guint callback_action,
 	GtkWidget *dialog;
 
 	command_open_file=NULL;
-	dialog=gtk_file_selection_new(_("ե򳫤"));
+	dialog=gtk_file_selection_new(_("Open"));
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
 	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(dialog)->ok_button),
 										"clicked",command_open_ok,dialog);
@@ -98,12 +98,10 @@ void command_save(gpointer callback_data,guint callback_action,
 	if (ptw->create) {
 		command_saveas(callback_data,callback_action,widget);
 	} else {
-		text=g_strdup_printf(
-				_("%s\nΥեϤǤ¸ߤޤ\n\n񤭤ޤ?"),
+		text=g_strdup_printf(_("%s\nThis file is existed.\n\nOver write?"),
 																	ptw->file);
 		if ((!ptw->overwrite || !isfile(ptw->file)
-			|| message_box("Text maid",text,1,
-										_("Ϥ(_Y)"),_("(_N)"),NULL)==0)
+			|| message_box("Text maid",text,1,_("_Yes"),_("_No"),NULL)==0)
 											&& save_text_file(ptw->file,ptw)) {
 			ptw->edit=FALSE;
 			if (delete_list(&ptw->undo)+delete_list(&ptw->redo)>0)
@@ -124,7 +122,7 @@ void command_saveas(gpointer callback_data,guint callback_action,
 						gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)));
 	ptw=gtk_object_get_user_data(GTK_OBJECT(child));
 	command_open_file=NULL;
-	dialog=gtk_file_selection_new(_("̾դ¸"));
+	dialog=gtk_file_selection_new(_("Save As"));
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
 	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(dialog)->ok_button),
 										"clicked",command_open_ok,dialog);
@@ -137,12 +135,10 @@ void command_saveas(gpointer callback_data,guint callback_action,
 	gtk_grab_add(dialog);
 	gtk_main();
 	if (command_open_file!=NULL) {
-		text=g_strdup_printf(
-				_("%s\nΥեϤǤ¸ߤޤ\n\n񤭤ޤ?"),
+		text=g_strdup_printf(_("%s\nThis file is existed.\n\nOver write?"),
 															command_open_file);
 		if ((!ptw->overwrite || !isfile(command_open_file)
-			|| message_box("Text maid",text,1,
-										_("Ϥ(_Y)"),_("(_N)"),NULL)==0)
+			|| message_box("Text maid",text,1,_("_Yes"),_("_No"),NULL)==0)
 									&& save_text_file(command_open_file,ptw)) {
 			g_free(savepath);
 			savepath=get_full_path(command_open_file);
@@ -182,10 +178,9 @@ void command_reload(gpointer callback_data,guint callback_action,
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
 	if (ptw->edit) {
-		text=g_strdup_printf(_("ե %s ƤѹƤޤ\n"
-								"¸Ƥ֤ᤷޤ?"),ptw->file);
-		result=message_box("Text maid",text,1,
-										_("Ϥ(_Y)"),_("(_N)"),NULL);
+		text=g_strdup_printf(
+				_("File %s was edited.\nRestore to existed file?"),ptw->file);
+		result=message_box("Text maid",text,1,_("_Yes"),_("_No"),NULL);
 		g_free(text);
 	}
 	if (result==0) {
@@ -426,8 +421,8 @@ void command_margin(gpointer callback_data,guint callback_action,
 {
 	TEXTWND *ptw;
 
-	if (message_box("Text maid",_("ޡǲԤޤ?"),1,
-									_("Ϥ(_Y)"),_("(_N)"),NULL)==0) {
+	if (message_box("Text maid",_("Return at Right Margin?"),1,
+												_("_Yes"),_("_No"),NULL)==0) {
 		ptw=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
@@ -441,8 +436,8 @@ void command_tab(gpointer callback_data,guint callback_action,
 {
 	TEXTWND *ptw;
 
-	if (message_box("Text maid",_("֤򥹥ڡѴޤ?"),1,
-									_("Ϥ(_Y)"),_("(_N)"),NULL)==0) {
+	if (message_box("Text maid",_("Convert Tab to Space?"),1,
+												_("_Yes"),_("_No"),NULL)==0) {
 		ptw=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
@@ -588,8 +583,8 @@ void command_next(gpointer callback_data,guint callback_action,
 	find_operation(ptw,&ptw->cursor,&ptw->select,find_text[0],
 					callback_action==0?find_arrow:!find_arrow,find_ignorecase);
 	if (userbreak && ptw->select.x<0) {
-		text=g_strdup_printf(_("'%s'Ĥޤ"),find_text[0]);
-		message_box("Text maid",text,0,_("λ"),NULL);
+		text=g_strdup_printf(_("'%s' was not fount."),find_text[0]);
+		message_box("Text maid",text,0,_("OK"),NULL);
 		g_free(text);
 		set_menu_bar(ptw);
 	}
@@ -701,12 +696,12 @@ void command_replace(gpointer callback_data,guint callback_action,
 			ptw->edit=TRUE;
 		} while (result>=0);
 		if (!replace) {
-			text=g_strdup_printf(_("'%s'Ĥޤ"),find_text[0]);
-			message_box("Text maid",text,0,_("λ"),NULL);
+			text=g_strdup_printf(_("'%s' was not fount."),find_text[0]);
+			message_box("Text maid",text,0,_("OK"),NULL);
 			g_free(text);
 		} else if (result>1) {
-			text=g_strdup_printf(_("%dĤʸִޤ"),count);
-			message_box("Text maid",text,0,_("λ"),NULL);
+			text=g_strdup_printf(_("%d strings were replaced"),count);
+			message_box("Text maid",text,0,_("OK"),NULL);
 			g_free(text);
 		}
 		set_menu_bar(ptw);
