@@ -66,8 +66,7 @@ static void conf_dialog_clicked(GtkWidget *widget,GtkWidget *dialog)
 		n_pos=GTK_POS_BOTTOM;
 	gtk_widget_destroy(dialog);
 	/*  */
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,
-													_("<main>/ե(F)"));
+	sub_menu=gtk_item_factory_get_widget(item_factory_menu,_("<main>/File"));
 	glist=gtk_container_children(GTK_CONTAINER(sub_menu));
 	for (i=g_list_length(glist)-3;i>history-(history==0)+MENUFILE-2;i--)
 		gtk_container_remove(GTK_CONTAINER(sub_menu),g_list_nth_data(glist,i));
@@ -113,7 +112,7 @@ void conf_dialog(void)
 
 	/* ᥤ󥦥ɥ */
 	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
-	gtk_window_set_title(GTK_WINDOW(dialog),_(""));
+	gtk_window_set_title(GTK_WINDOW(dialog),_("Configuration"));
 	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
 								GTK_SIGNAL_FUNC(conf_dialog_key_press),NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
@@ -121,8 +120,8 @@ void conf_dialog(void)
 	accel=gtk_accel_group_new();
 	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
 	/* ܥ */
-	button0=gtk_button_new_with_label(_("λ"));
-	button1=gtk_button_new_with_label(_(""));
+	button0=gtk_button_new_with_label(_("OK"));
+	button1=gtk_button_new_with_label(_("Cancel"));
 	gtk_signal_connect(GTK_OBJECT(button0),"clicked",
 												conf_dialog_clicked,dialog);
 	gtk_signal_connect_object(GTK_OBJECT(button1),"clicked",
@@ -133,10 +132,10 @@ void conf_dialog(void)
 	check0=gtk_check_button_new_with_label(NULL);
 	check1=gtk_check_button_new_with_label(NULL);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check0)->child),
-												_("ե򳫤(_N)"));
+															_("_New File"));
 	gtk_widget_add_accelerator(check0,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check1)->child),
-												_("ɥ򳫤(_O)"));
+															_("_Open Window"));
 	gtk_widget_add_accelerator(check1,"clicked",accel,key,GDK_MOD1_MASK,0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check0),newfile);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check1),second);
@@ -168,11 +167,11 @@ void conf_dialog(void)
 	label0=gtk_label_new(NULL);
 	label1=gtk_label_new(NULL);
 	label2=gtk_label_new(NULL);
-	key=gtk_label_parse_uline(GTK_LABEL(label0),_("ե(_I)"));
+	key=gtk_label_parse_uline(GTK_LABEL(label0),_("H_istory"));
 	gtk_widget_add_accelerator(spin0,"grab-focus",accel,key,GDK_MOD1_MASK,0);
-	key=gtk_label_parse_uline(GTK_LABEL(label1),_("(_W)"));
+	key=gtk_label_parse_uline(GTK_LABEL(label1),_("_Width"));
 	gtk_widget_add_accelerator(spin1,"grab-focus",accel,key,GDK_MOD1_MASK,0);
-	key=gtk_label_parse_uline(GTK_LABEL(label2),_("⤵(_H)"));
+	key=gtk_label_parse_uline(GTK_LABEL(label2),_("_Height"));
 	gtk_widget_add_accelerator(spin2,"grab-focus",accel,key,GDK_MOD1_MASK,0);
 	/* 饸ܥ */
 	radio0=gtk_radio_button_new_with_label(NULL,NULL);
@@ -182,13 +181,13 @@ void conf_dialog(void)
 												GTK_RADIO_BUTTON(radio1),NULL);
 	radio3=gtk_radio_button_new_with_label_from_widget(
 												GTK_RADIO_BUTTON(radio2),NULL);
-	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),_("(_T)"));
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),_("_Top"));
 	gtk_widget_add_accelerator(radio0,"clicked",accel,key,GDK_MOD1_MASK,0);
-	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),_("(_L)"));
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),_("_Left"));
 	gtk_widget_add_accelerator(radio1,"clicked",accel,key,GDK_MOD1_MASK,0);
-	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio2)->child),_("(_R)"));
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio2)->child),_("_Right"));
 	gtk_widget_add_accelerator(radio2,"clicked",accel,key,GDK_MOD1_MASK,0);
-	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio3)->child),_("(_B)"));
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio3)->child),_("_Bottom"));
 	gtk_widget_add_accelerator(radio3,"clicked",accel,key,GDK_MOD1_MASK,0);
 	switch (n_pos) {
 		case GTK_POS_TOP:	gtk_toggle_button_set_active(
@@ -205,7 +204,7 @@ void conf_dialog(void)
 	gtk_signal_connect(GTK_OBJECT(radio2),"toggled",conf_dialog_toggled,NULL);
 	gtk_signal_connect(GTK_OBJECT(radio3),"toggled",conf_dialog_toggled,NULL);
 	/* ե졼ȥܥå */
-	frame0=gtk_frame_new(_("ɥΥ"));
+	frame0=gtk_frame_new(_("Window Size"));
 	hbox0=gtk_hbox_new(FALSE,8);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox0),8);
 	hbox1=gtk_hbox_new(FALSE,0);
@@ -218,7 +217,7 @@ void conf_dialog(void)
 	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,0);
 	gtk_container_add(GTK_CONTAINER(frame0),hbox0);
 
-	frame1=gtk_frame_new(_("֤ΰ"));
+	frame1=gtk_frame_new(_("Tab Position"));
 	vbox=gtk_vbox_new(FALSE,8);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
 	hbox0=gtk_hbox_new(FALSE,8);
