@@ -39,8 +39,7 @@ void set_history(gchar *file)
 	GList *glist;
 	GtkWidget *sub_menu,*menu_item;
 
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,
-													_("<main>/ե(F)"));
+	sub_menu=gtk_item_factory_get_widget(item_factory_menu,_("<main>/File"));
 	glist=gtk_container_children(GTK_CONTAINER(sub_menu));
 	count=g_list_length(glist);
 	for (i=0;i<count-MENUFILE-1;i++) {
@@ -205,7 +204,7 @@ void open_text_file(TEXTWND *ptw)
 	ptw->start=p;
 	/* ܥå */
 	userbreak=TRUE;
-	dialog=abort_dialog(_("եɤ߹"));
+	dialog=abort_dialog(_("Reading"));
 	gtk_grab_add(dialog);
 	while ((c=fgetc(fp))!=EOF && userbreak) {
 		while (gtk_events_pending())
@@ -348,27 +347,30 @@ TEXTWND *open_edit_file(gchar *file)
 	/* ɽꥢ */
 	ptw->drawing=gtk_drawing_area_new();
 	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"focus-in-event",
-									GTK_SIGNAL_FUNC(signal_focus_in),ptw);
+								GTK_SIGNAL_FUNC(signal_focus_in),ptw);
 	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"focus-out-event",
-									GTK_SIGNAL_FUNC(signal_focus_out),ptw);
+								GTK_SIGNAL_FUNC(signal_focus_out),ptw);
 	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"realize",
-									GTK_SIGNAL_FUNC(signal_realize),ptw);
+								GTK_SIGNAL_FUNC(signal_realize),ptw);
 	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"unrealize",
-									GTK_SIGNAL_FUNC(signal_unrealize),ptw);
+								GTK_SIGNAL_FUNC(signal_unrealize),ptw);
 	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"configure-event",
-									GTK_SIGNAL_FUNC(signal_config),ptw);
+								GTK_SIGNAL_FUNC(signal_config),ptw);
 	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"expose-event",
-									GTK_SIGNAL_FUNC(signal_expose),ptw);
+								GTK_SIGNAL_FUNC(signal_expose),ptw);
 	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"button-press-event",
-									GTK_SIGNAL_FUNC(signal_button_press),ptw);
+								GTK_SIGNAL_FUNC(signal_button_press),ptw);
 	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"motion-notify-event",
-									GTK_SIGNAL_FUNC(signal_motion_notify),ptw);
+								GTK_SIGNAL_FUNC(signal_motion_notify),ptw);
+	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"button-release-event",
+								GTK_SIGNAL_FUNC(signal_button_release),ptw);
 	gtk_signal_connect_after(GTK_OBJECT(ptw->drawing),"key-press-event",
-									GTK_SIGNAL_FUNC(signal_key_press),ptw);
+								GTK_SIGNAL_FUNC(signal_key_press),ptw);
 	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"destroy",
-									GTK_SIGNAL_FUNC(signal_destroy_draw),ptw);
+								GTK_SIGNAL_FUNC(signal_destroy_draw),ptw);
 	gtk_widget_add_events(ptw->drawing,GDK_FOCUS_CHANGE | GDK_BUTTON_PRESS_MASK
-					| GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK);
+					| GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK
+														| GDK_BUTTON_RELEASE);
 	GTK_WIDGET_SET_FLAGS(ptw->drawing,GTK_CAN_FOCUS);
 	/* ץ饤ޥꥻ쥯 */
 	gtk_selection_add_targets(ptw->drawing,GDK_SELECTION_PRIMARY,targets,
@@ -391,8 +393,7 @@ TEXTWND *open_edit_file(gchar *file)
 							GTK_FILL,GTK_EXPAND | GTK_SHRINK | GTK_FILL,0,0);
 	gtk_object_set_user_data(GTK_OBJECT(table),ptw);
 	/* ˥塼 */
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,
-													_("<main>/ɥ(W)"));
+	sub_menu=gtk_item_factory_get_widget(item_factory_menu,_("<main>/Window"));
 	ptw->menu_item=gtk_menu_item_new_with_label(ptw->file);
 	gtk_signal_connect(GTK_OBJECT(ptw->menu_item),"activate",
 						GTK_SIGNAL_FUNC(signal_activate_menu_window),table);
@@ -449,12 +450,12 @@ gboolean save_text_file(gchar *file,TEXTWND *ptw)
 		p=p->prev;
 	/*  */
 	if ((fp=fopen(file,"wt"))==NULL) {
-		message_box("Text maid",_("ե뤬ޤ"),0,_("λ"),NULL);
+		message_box("Text maid",_("Can not open file"),0,_("OK"),NULL);
 		return FALSE;
 	}
 	/* ܥå */
 	userbreak=TRUE;
-	dialog=abort_dialog(_("ե˽񤭹"));
+	dialog=abort_dialog(_("Writing"));
 	gtk_grab_add(dialog);
 	/*  */
 	while (p!=NULL && userbreak) {
@@ -463,8 +464,7 @@ gboolean save_text_file(gchar *file,TEXTWND *ptw)
 		if (p->length>0 && fwrite(p->text,1,p->length,fp)!=p->length) {
 			gtk_grab_remove(dialog);
 			gtk_widget_destroy(dialog);
-			message_box("Text maid",_("ե˽񤭹ߤǤޤ"),0,
-															_("λ"),NULL);
+			message_box("Text maid",_("Can not write"),0,_("OK"),NULL);
 			fclose(fp);
 			return FALSE;
 		}
@@ -472,8 +472,7 @@ gboolean save_text_file(gchar *file,TEXTWND *ptw)
 			if (fputc('\n',fp)==EOF) {
 				gtk_grab_remove(dialog);
 				gtk_widget_destroy(dialog);
-				message_box("Text maid",_("ե˽񤭹ߤǤޤ"),0,
-															_("λ"),NULL);
+				message_box("Text maid",_("Can not write"),0,_("OK"),NULL);
 				fclose(fp);
 				return FALSE;
 			}
@@ -487,8 +486,7 @@ gboolean save_text_file(gchar *file,TEXTWND *ptw)
 	if (userbreak && !eof && ptw->eof && fputc('\x1a',fp)==EOF) {
 		gtk_grab_remove(dialog);
 		gtk_widget_destroy(dialog);
-		message_box("Text maid",_("ե˽񤭹ߤǤޤ"),0,
-															_("λ"),NULL);
+		message_box("Text maid",_("Can not write"),0,_("OK"),NULL);
 		fclose(fp);
 		return FALSE;
 	}
@@ -496,7 +494,7 @@ gboolean save_text_file(gchar *file,TEXTWND *ptw)
 	gtk_grab_remove(dialog);
 	gtk_widget_destroy(dialog);
 	if (fclose(fp)!=0) {
-		message_box("Text maid","fclose",0,_("λ"),NULL);
+		message_box("Text maid","fclose",0,_("OK"),NULL);
 		return FALSE;
 	}
 	return TRUE;
