@@ -33,153 +33,6 @@ gchar *find_text[32];						/* ʸ */
 gint find_num=0;							/* ϿƤ븡ʸ */
 
 
-/******************************************************************************
-*                                                                             *
-*                                                             *
-*                                                                             *
-******************************************************************************/
-static gboolean find_clicked_ok;
-static GtkWidget *dialog,*check,*combo,*radio1;
-
-
-/* OKܥ󤬲줿 */
-static void find_dialog_clicked(GtkWidget *widget,FIND *fd)
-{
-	fd->text=g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo)->entry)));
-	fd->ignorecase=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check));
-	fd->arrow=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio1));
-	gtk_widget_destroy(dialog);
-	find_clicked_ok=TRUE;
-}
-
-
-/* ȥ꡼ǥ꥿󤬲줿 */
-static void find_dialog_activate(GtkWidget *widget,FIND *fd)
-{
-	if (strlen(gtk_entry_get_text(GTK_ENTRY(widget)))>0)
-		find_dialog_clicked(widget,fd);
-}
-
-
-/* ȥ꡼ѹ줿 */
-static void find_dialog_changed(GtkWidget *widget,GtkWidget *button)
-{
-	gtk_widget_set_sensitive(button,
-							strlen(gtk_entry_get_text(GTK_ENTRY(widget)))>0);
-}
-
-
-/* ESC줿 */
-static gboolean find_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
-															gpointer user_data)
-{
-	if (event->keyval==GDK_Escape)
-		gtk_widget_destroy(widget);
-	return FALSE;
-}
-
-
-gboolean find_dialog(FIND *fd)
-{
-	gint i;
-	guint key;
-	GList *glist=NULL;
-	GtkAccelGroup *accel;
-	GtkWidget *radio0,*button0,*button1,*frame0,*frame1,*hbox,*tbox,*vbox;
-
-	/* ᥤ󥦥ɥ */
-	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
-	gtk_window_set_title(GTK_WINDOW(dialog),_(""));
-	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
-								GTK_SIGNAL_FUNC(find_dialog_key_press),NULL);
-	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
-	/* 졼 */
-	accel=gtk_accel_group_new();
-	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
-	/* ܥ */
-	button0=gtk_button_new_with_label(NULL);
-	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button0)->child),
-																_("(_F)"));
-	gtk_widget_add_accelerator(button0,"clicked",accel,key,GDK_MOD1_MASK,0);
-	button1=gtk_button_new_with_label(_(""));
-	gtk_signal_connect(GTK_OBJECT(button0),"clicked",find_dialog_clicked,fd);
-	gtk_signal_connect_object(GTK_OBJECT(button1),"clicked",
-										gtk_widget_destroy,GTK_OBJECT(dialog));
-	GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
-	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
-	/* åܥ */
-	check=gtk_check_button_new_with_label(NULL);
-	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check)->child),
-											_("ʸ/ʸ̤(_C)"));
-	gtk_widget_add_accelerator(check,"clicked",accel,key,GDK_MOD1_MASK,0);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),fd->ignorecase);
-	/* ܥܥå */
-	for (i=0;i<find_num;i++)
-		glist=g_list_append(glist,find_text[i]);
-	combo=gtk_combo_new();
-	if (find_num>0) {
-		gtk_combo_set_popdown_strings(GTK_COMBO(combo),glist);
-		gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(combo)->entry),find_text[0]);
-		gtk_editable_select_region(GTK_EDITABLE(GTK_COMBO(combo)->entry),0,-1);
-	}
-	gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo)->entry),"activate",
-												find_dialog_activate,fd);
-	gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo)->entry),"changed",
-												find_dialog_changed,button0);
-	/* 饸ܥ */
-	radio0=gtk_radio_button_new_with_label(NULL,NULL);
-	radio1=gtk_radio_button_new_with_label_from_widget(
-												GTK_RADIO_BUTTON(radio0),NULL);
-	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),_("(_U)"));
-	gtk_widget_add_accelerator(radio0,"clicked",accel,key,GDK_MOD1_MASK,0);
-	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),_("(_D)"));
-	gtk_widget_add_accelerator(radio1,"clicked",accel,key,GDK_MOD1_MASK,0);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(fd->arrow?radio1:radio0),
-																		TRUE);
-	/* ե졼ȥܥå */
-	tbox=gtk_vbox_new(FALSE,8);
-	gtk_container_set_border_width(GTK_CONTAINER(tbox),8);
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),
-								gtk_label_new(_("ʸ")),FALSE,FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),combo,TRUE,TRUE,0);
-	gtk_box_pack_start(GTK_BOX(tbox),hbox,FALSE,FALSE,0);
-	frame0=gtk_frame_new(_("ץ"));
-	vbox=gtk_vbox_new(FALSE,8);
-	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
-	gtk_box_pack_start(GTK_BOX(vbox),check,FALSE,FALSE,0);
-	gtk_container_add(GTK_CONTAINER(frame0),vbox);
-	frame1=gtk_frame_new(_(""));
-	vbox=gtk_vbox_new(FALSE,8);
-	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
-	gtk_box_pack_start(GTK_BOX(vbox),radio0,FALSE,FALSE,0);
-	gtk_box_pack_start(GTK_BOX(vbox),radio1,FALSE,FALSE,0);
-	gtk_container_add(GTK_CONTAINER(frame1),vbox);
-	hbox=gtk_hbox_new(FALSE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),frame0,TRUE,TRUE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),frame1,TRUE,TRUE,0);
-	gtk_box_pack_start(GTK_BOX(tbox),hbox,TRUE,TRUE,0);
-	hbox=gtk_hbox_new(FALSE,8);
-	gtk_box_pack_end(GTK_BOX(hbox),button1,FALSE,FALSE,0);
-	gtk_box_pack_end(GTK_BOX(hbox),button0,FALSE,FALSE,0);
-	gtk_box_pack_end(GTK_BOX(tbox),hbox,FALSE,FALSE,0);
-	gtk_container_add(GTK_CONTAINER(dialog),tbox);
-
-	/* ɽ */
-	gtk_widget_set_sensitive(button0,
-			strlen(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo)->entry)))>0);
-	gtk_widget_grab_focus(GTK_COMBO(combo)->entry);
-	find_clicked_ok=FALSE;
-
-	gtk_window_set_policy(GTK_WINDOW(dialog),FALSE,TRUE,FALSE);
-	gtk_grab_add(dialog);
-	gtk_widget_show_all(dialog);
-	gtk_main();
-
-	return find_clicked_ok;
-}
-
-
 /******************************************************************************
 *                                                                             *
 * ؿ                                                                  *
@@ -266,7 +119,7 @@ void find_operation(TEXTWND *ptw,GdkPoint *start,GdkPoint *end,
 		return;/* ϰϤ̷⤹Ȥ */
 	/* ܥå */
 	userbreak=TRUE;
-	dialog=abort_dialog(_(""));
+	dialog=abort_dialog(_("Finding"));
 	gtk_grab_add(dialog);
 	ed.x=get_data_pos(ptw,ed.x,ed.y,FALSE);
 	st.x=get_data_pos(ptw,st.x,st.y,FALSE);
@@ -457,3 +310,149 @@ void find_operation(TEXTWND *ptw,GdkPoint *start,GdkPoint *end,
 															GDK_CURRENT_TIME);
 	}
 }
+
+
+/******************************************************************************
+*                                                                             *
+*                                                             *
+*                                                                             *
+******************************************************************************/
+static gboolean find_clicked_ok;
+static GtkWidget *dialog,*check,*combo,*radio1;
+
+
+/* OKܥ󤬲줿 */
+static void find_dialog_clicked(GtkWidget *widget,FIND *fd)
+{
+	fd->text=g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo)->entry)));
+	fd->ignorecase=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check));
+	fd->arrow=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio1));
+	gtk_widget_destroy(dialog);
+	find_clicked_ok=TRUE;
+}
+
+
+/* ȥ꡼ǥ꥿󤬲줿 */
+static void find_dialog_activate(GtkWidget *widget,FIND *fd)
+{
+	if (strlen(gtk_entry_get_text(GTK_ENTRY(widget)))>0)
+		find_dialog_clicked(widget,fd);
+}
+
+
+/* ȥ꡼ѹ줿 */
+static void find_dialog_changed(GtkWidget *widget,GtkWidget *button)
+{
+	gtk_widget_set_sensitive(button,
+							strlen(gtk_entry_get_text(GTK_ENTRY(widget)))>0);
+}
+
+
+/* ESC줿 */
+static gboolean find_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
+															gpointer user_data)
+{
+	if (event->keyval==GDK_Escape)
+		gtk_widget_destroy(widget);
+	return FALSE;
+}
+
+
+gboolean find_dialog(FIND *fd)
+{
+	gint i;
+	guint key;
+	GList *glist=NULL;
+	GtkAccelGroup *accel;
+	GtkWidget *radio0,*button0,*button1,*frame0,*frame1,*hbox,*tbox,*vbox;
+
+	/* ᥤ󥦥ɥ */
+	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
+	gtk_window_set_title(GTK_WINDOW(dialog),_("Find"));
+	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
+								GTK_SIGNAL_FUNC(find_dialog_key_press),NULL);
+	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
+	/* 졼 */
+	accel=gtk_accel_group_new();
+	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
+	/* ܥ */
+	button0=gtk_button_new_with_label(NULL);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button0)->child),_("_Find"));
+	gtk_widget_add_accelerator(button0,"clicked",accel,key,GDK_MOD1_MASK,0);
+	button1=gtk_button_new_with_label(_("Cancel"));
+	gtk_signal_connect(GTK_OBJECT(button0),"clicked",find_dialog_clicked,fd);
+	gtk_signal_connect_object(GTK_OBJECT(button1),"clicked",
+										gtk_widget_destroy,GTK_OBJECT(dialog));
+	GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
+	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
+	/* åܥ */
+	check=gtk_check_button_new_with_label(NULL);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check)->child),
+															_("Enable _Case"));
+	gtk_widget_add_accelerator(check,"clicked",accel,key,GDK_MOD1_MASK,0);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),fd->ignorecase);
+	/* ܥܥå */
+	for (i=0;i<find_num;i++)
+		glist=g_list_append(glist,find_text[i]);
+	combo=gtk_combo_new();
+	if (find_num>0) {
+		gtk_combo_set_popdown_strings(GTK_COMBO(combo),glist);
+		gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(combo)->entry),find_text[0]);
+		gtk_editable_select_region(GTK_EDITABLE(GTK_COMBO(combo)->entry),0,-1);
+	}
+	gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo)->entry),"activate",
+												find_dialog_activate,fd);
+	gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo)->entry),"changed",
+												find_dialog_changed,button0);
+	/* 饸ܥ */
+	radio0=gtk_radio_button_new_with_label(NULL,NULL);
+	radio1=gtk_radio_button_new_with_label_from_widget(
+												GTK_RADIO_BUTTON(radio0),NULL);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),_("_Up"));
+	gtk_widget_add_accelerator(radio0,"clicked",accel,key,GDK_MOD1_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),_("_Down"));
+	gtk_widget_add_accelerator(radio1,"clicked",accel,key,GDK_MOD1_MASK,0);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(fd->arrow?radio1:radio0),
+																		TRUE);
+	/* ե졼ȥܥå */
+	tbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(tbox),8);
+	hbox=gtk_hbox_new(FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),
+								gtk_label_new(_("Find String")),FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),combo,TRUE,TRUE,0);
+	gtk_box_pack_start(GTK_BOX(tbox),hbox,FALSE,FALSE,0);
+	frame0=gtk_frame_new(_("Option"));
+	vbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	gtk_box_pack_start(GTK_BOX(vbox),check,FALSE,FALSE,0);
+	gtk_container_add(GTK_CONTAINER(frame0),vbox);
+	frame1=gtk_frame_new(_("Direction"));
+	vbox=gtk_vbox_new(FALSE,8);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	gtk_box_pack_start(GTK_BOX(vbox),radio0,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),radio1,FALSE,FALSE,0);
+	gtk_container_add(GTK_CONTAINER(frame1),vbox);
+	hbox=gtk_hbox_new(FALSE,8);
+	gtk_box_pack_start(GTK_BOX(hbox),frame0,TRUE,TRUE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),frame1,TRUE,TRUE,0);
+	gtk_box_pack_start(GTK_BOX(tbox),hbox,TRUE,TRUE,0);
+	hbox=gtk_hbox_new(FALSE,8);
+	gtk_box_pack_end(GTK_BOX(hbox),button1,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(hbox),button0,FALSE,FALSE,0);
+	gtk_box_pack_end(GTK_BOX(tbox),hbox,FALSE,FALSE,0);
+	gtk_container_add(GTK_CONTAINER(dialog),tbox);
+
+	/* ɽ */
+	gtk_widget_set_sensitive(button0,
+			strlen(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo)->entry)))>0);
+	gtk_widget_grab_focus(GTK_COMBO(combo)->entry);
+	find_clicked_ok=FALSE;
+
+	gtk_window_set_policy(GTK_WINDOW(dialog),FALSE,TRUE,FALSE);
+	gtk_grab_add(dialog);
+	gtk_widget_show_all(dialog);
+	gtk_main();
+
+	return find_clicked_ok;
+}
