@@ -91,7 +91,7 @@ void draw_caret(TEXTWND *ptw,GdkPoint *cursor)
 	if (timer_id==0)
 		timer_id=gtk_timeout_add(500,signal_timeout,NULL);
 	text=g_strdup_printf(ptw->select.x<0
-			?_("%d,%d"):_("%d,%d  ϰ(%d,%d)-(%d,%d)"),
+							?_("%d,%d"):_("%d,%d  Selected(%d,%d)-(%d,%d)"),
 							x+1,y+1,ptw->select.x+1,ptw->select.y+1,x+1,y+1);
 	context_id=gtk_statusbar_get_context_id(GTK_STATUSBAR(status),"Status");
 	gtk_statusbar_pop(GTK_STATUSBAR(status),context_id);
@@ -118,39 +118,38 @@ void set_menu_bar(TEXTWND *ptw)
 	if (ptw!=NULL) {
 		gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
 								gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/Խ(E)")))),TRUE);
+									_("<main>/Edit")))),TRUE);
 		gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
 								gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/(S)")))),TRUE);
+									_("<main>/Search")))),TRUE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/ե(F)/Ĥ(C)")),TRUE);
+									_("<main>/File/Close")),TRUE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/ե(F)/¸(S)")),TRUE);
+									_("<main>/File/Save")),TRUE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/ե(F)/̾Ĥ¸(A)...")),TRUE);
+									_("<main>/File/Save As...")),TRUE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/ե(F)/¸Ƥ֤᤹(R)...")),
-																!ptw->create);
+									_("<main>/File/Reload")),!ptw->create);
 #ifdef USE_GDKPIXBUF
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/ե(F)/(P)...")),TRUE);
+									_("<main>/File/Print...")),TRUE);
 #endif
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/ե(F)/ץѥƥ(I)...")),TRUE);
+									_("<main>/File/Properties...")),TRUE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/Խ(E)/᤹(U)")),ptw->undo!=NULL);
+									_("<main>/Edit/Undo")),ptw->undo!=NULL);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/Խ(E)/ľ(R)")),ptw->redo!=NULL);
+									_("<main>/Edit/Redo")),ptw->redo!=NULL);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/Խ(E)/ڤ(T)")),ptw->select.x>=0);
+									_("<main>/Edit/Cut")),ptw->select.x>=0);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/Խ(E)/ԡ(C)")),ptw->select.x>=0);
+									_("<main>/Edit/Copy")),ptw->select.x>=0);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/Խ(E)/(L)")),ptw->select.x>=0);
+									_("<main>/Edit/Delete")),ptw->select.x>=0);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/(S)/򸡺(N)")),find_num>0);
+									_("<main>/Search/Next")),find_num>0);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/(S)/դ򸡺(B)")),find_num>0);
+									_("<main>/Search/Previous")),find_num>0);
 		gtk_widget_set_sensitive(toolbar_items[ 2].item,TRUE);
 		gtk_widget_set_sensitive(toolbar_items[ 4].item,TRUE);
 #ifdef USE_GDKPIXBUF
@@ -176,24 +175,24 @@ void set_menu_bar(TEXTWND *ptw)
 	} else {
 		gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
 								gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/Խ(E)")))),FALSE);
+									_("<main>/Edit")))),FALSE);
 		gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
 								gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/(S)")))),FALSE);
+									_("<main>/Search")))),FALSE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/ե(F)/Ĥ(C)")),FALSE);
+									_("<main>/File/Close")),FALSE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/ե(F)/¸(S)")),FALSE);
+									_("<main>/File/Save")),FALSE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/ե(F)/̾Ĥ¸(A)...")),FALSE);
+									_("<main>/File/Save As...")),FALSE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/ե(F)/¸Ƥ֤᤹(R)...")),FALSE);
+									_("<main>/File/Reload")),FALSE);
 #ifdef USE_GDKPIXBUF
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/ե(F)/(P)...")),FALSE);
+									_("<main>/File/Print...")),FALSE);
 #endif
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
-				_("<main>/ե(F)/ץѥƥ(I)...")),FALSE);
+									_("<main>/File/Properties...")),FALSE);
 		gtk_widget_set_sensitive(toolbar_items[ 2].item,FALSE);
 		gtk_widget_set_sensitive(toolbar_items[ 4].item,FALSE);
 #ifdef USE_GDKPIXBUF
@@ -217,8 +216,7 @@ void set_menu_bar(TEXTWND *ptw)
 		gtk_widget_set_sensitive(toolbar_items[15].item,FALSE);
 #endif
 	}
-	menu=gtk_item_factory_get_widget(item_factory_menu,
-													_("<main>/ɥ(W)"));
+	menu=gtk_item_factory_get_widget(item_factory_menu,_("<main>/Window"));
 	glist=gtk_container_children(GTK_CONTAINER(menu));
 	gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(menu)),
 													g_list_length(glist)>0);
@@ -615,11 +613,9 @@ gboolean prompt_close(TEXTWND *ptw)
 	gchar *text;
 
 	if (ptw->edit) {
-		text=g_strdup_printf(
-					_("ե %s ƤѹƤޤ\n¸ޤ?"),
-																	ptw->file);
+		text=g_strdup_printf(_("File %s was edited\nSave?"),ptw->file);
 		switch (message_box("Text maid",text,0,
-						_("Ϥ(_Y)"),_("(_N)"),_("󥻥"),NULL)) {
+										_("_Yes"),_("_No"),_("Cancel"),NULL)) {
 			case 0:
 				command_save(NULL,0,NULL);
 				if (!ptw->edit)
