@@ -44,7 +44,7 @@ void clear_sel(TEXTWND *ptw,GdkPoint *start,GdkPoint *end);
 /*	ư
 	ptw,TXTɥ
 	top,Ťκɸ														*/
-void move_text_window(TEXTWND *ptw,GdkPoint *top);
+void move_edit_window(TEXTWND *ptw,GdkPoint *top);
 
 
 /*	åȰ֤˥ǡ/񤭤
