@@ -131,13 +131,13 @@ gboolean jump_dialog(JMPDLG *jmp)
 
 	/* ᥤ󥦥ɥ */
 	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
-	gtk_window_set_title(GTK_WINDOW(dialog),_("Ԥذư"));
+	gtk_window_set_title(GTK_WINDOW(dialog),_("Jump"));
 	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
 								GTK_SIGNAL_FUNC(jump_dialog_key_press),NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
 	/* ܥ */
-	button0=gtk_button_new_with_label(_("λ"));
-	button1=gtk_button_new_with_label(_(""));
+	button0=gtk_button_new_with_label(_("OK"));
+	button1=gtk_button_new_with_label(_("Cancel"));
 	gtk_signal_connect(GTK_OBJECT(button0),"clicked",jump_dialog_clicked,jmp);
 	gtk_signal_connect_object(GTK_OBJECT(button1),"clicked",
 										gtk_widget_destroy,GTK_OBJECT(dialog));
@@ -155,7 +155,7 @@ gboolean jump_dialog(JMPDLG *jmp)
 	vbox=gtk_vbox_new(FALSE,8);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
 	gtk_box_pack_start(GTK_BOX(vbox),entry,TRUE,TRUE,0);
-	hbox=gtk_hbox_new(FALSE,7);
+	hbox=gtk_hbox_new(FALSE,8);
 	gtk_box_pack_end(GTK_BOX(hbox),button1,FALSE,FALSE,0);
 	gtk_box_pack_end(GTK_BOX(hbox),button0,FALSE,FALSE,0);
 	gtk_box_pack_end(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
