@@ -35,10 +35,11 @@ static GtkWidget *button0,*button3;
 static GtkWidget *check0,*check1,*check2,*check3,*check4,*check5,*check6;
 static GtkWidget *check7,*check8,*check9,*check10,*check11,*check12;
 static GtkWidget *clist,*entry0,*entry1,*label,*spin0,*spin1;
-static gchar *color_name[12]={N_("ʸ"),N_("ط"),N_("ȥ륳"),
-					N_("ѥڡ"),N_("ԥ"),N_("ֲ"),
-					N_("ޡ"),N_("å"),N_("򤵤줿ʸ"),
-					N_("򤵤줿ط"),N_("ʸ()"),N_("ط()")};
+static gchar *color_name[12]={
+	N_("Foreground"),N_("Background"),N_("Control Code"),
+	N_("Full Width Space"),N_("Return Code"),N_("Tab Under Line"),
+	N_("Right Margin"),N_("Grid"),N_("Selected Foreground"),
+	N_("Selected Background"),N_("Foreground(Print)"),N_("Background(Print)")};
 
 
 /* OKܥɽ/ɽȽ */
@@ -124,7 +125,7 @@ static void property_dialog_clicked_color(GtkWidget *widget,gpointer user_data)
 	gdouble color[4];
 	GtkWidget *dialog_color;
 
-	dialog_color=gtk_color_selection_dialog_new(_(""));
+	dialog_color=gtk_color_selection_dialog_new(_("Color Configuration"));
 	gtk_signal_connect(GTK_OBJECT(dialog_color),"destroy",gtk_main_quit,NULL);
 	gtk_signal_connect(GTK_OBJECT(
 					GTK_COLOR_SELECTION_DIALOG(dialog_color)->ok_button),
@@ -171,7 +172,7 @@ static void property_dialog_clicked_font(GtkWidget *widget,gpointer user_data)
 {
 	GtkWidget *dialog_font;
 
-	dialog_font=gtk_font_selection_dialog_new(_("ե"));
+	dialog_font=gtk_font_selection_dialog_new(_("Font"));
 	gtk_signal_connect(GTK_OBJECT(dialog_font),"destroy",gtk_main_quit,NULL);
 	gtk_signal_connect(GTK_OBJECT(
 						GTK_FONT_SELECTION_DIALOG(dialog_font)->ok_button),
@@ -230,7 +231,7 @@ static void property_dialog_clicked_ftype(GtkWidget *widget,gpointer user_data)
 			gtk_widget_set_sensitive(button3,TRUE);
 		} else {
 			ft_id=-1;
-			gtk_label_set_text(GTK_LABEL(label),_("ե륿פʤ"));
+			gtk_label_set_text(GTK_LABEL(label),_("Independent File Type"));
 			property_dialog_ok_sensitive(NULL,NULL);
 		}
 	}
@@ -308,7 +309,7 @@ gboolean property_dialog(FTYPE *ft)
 	/* ᥤ󥦥ɥ */
 	dialog=gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(dialog),ft->text==NULL || ft->ext==NULL
-								?_("ץѥƥ"):_("ե륿פξܺ"));
+									?_("Property"):_("Details of File Type"));
 	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
 							GTK_SIGNAL_FUNC(property_dialog_key_press),NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
@@ -320,17 +321,16 @@ gboolean property_dialog(FTYPE *ft)
 	button1=gtk_button_new_with_label(NULL);
 	button2=ft->text==NULL && ft->ext==NULL
 										?gtk_button_new_with_label(NULL):NULL;
-	button3=gtk_button_new_with_label(_("λ"));
-	button4=gtk_button_new_with_label(_(""));
+	button3=gtk_button_new_with_label(_("OK"));
+	button4=gtk_button_new_with_label(_("Cancel"));
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button0)->child),
-																_("ѹ(_P)"));
+																_("_Palette"));
 	gtk_widget_add_accelerator(button0,"clicked",accel,key,GDK_MOD1_MASK,0);
-	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button1)->child),
-															_("ե(_F)"));
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button1)->child),_("_Font"));
 	gtk_widget_add_accelerator(button1,"clicked",accel,key,GDK_MOD1_MASK,0);
 	if (button2!=NULL) {
 		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button2)->child),
-													_("ե륿(_A)"));
+													_("Associated File Type"));
 		gtk_widget_add_accelerator(button2,"clicked",accel,key,
 															GDK_MOD1_MASK,0);
 	}
@@ -364,39 +364,39 @@ gboolean property_dialog(FTYPE *ft)
 	check9=gtk_check_button_new_with_label(NULL);
 	check10=gtk_check_button_new_with_label(NULL);
 	check11=gtk_check_button_new_with_label(NULL);
-	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check0)->child),
-															_("å(_G)"));
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check0)->child),_("_Grid"));
 	gtk_widget_add_accelerator(check0,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check1)->child),
-														_("ѥڡ(_S)"));
+													_("Full Width _Space"));
 	gtk_widget_add_accelerator(check1,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check2)->child),
-														_("ԥ(_E)"));
+															_("R_eturn Code"));
 	gtk_widget_add_accelerator(check2,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check3)->child),
-													_("ޡɽ(_M)"));
+													_("Show Right _Margin"));
 	gtk_widget_add_accelerator(check3,"clicked",accel,key,GDK_MOD1_MASK,0);
-	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check4)->child),
-															_("ޤ֤(_I)"));
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check4)->child),_("_Turn"));
 	gtk_widget_add_accelerator(check4,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check5)->child),
-														_("ʸ(_C)"));
+														_("_Control Mark"));
 	gtk_widget_add_accelerator(check5,"clicked",accel,key,GDK_MOD1_MASK,0);
-	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check6)->child),_("(_U)"));
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check6)->child),
+															_("_Under Line"));
 	gtk_widget_add_accelerator(check6,"clicked",accel,key,GDK_MOD1_MASK,0);
-	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check7)->child),_("(_V)"));
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check7)->child),
+														_("_Vertical Line"));
 	gtk_widget_add_accelerator(check7,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check8)->child),
-														_("ư(_N)"));
+															_("Auto I_ndent"));
 	gtk_widget_add_accelerator(check8,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check9)->child),
-									_("եκǸ^Z(1A)դ(_Z)"));
+													_("Append ^_Z at EOF"));
 	gtk_widget_add_accelerator(check9,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check10)->child),
-												_("¸ǧ(_O)"));
+											_("_Over Write with Agreement"));
 	gtk_widget_add_accelerator(check10,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check11)->child),
-													_("ƥ࿧Ȥ(_Y)"));
+													_("Use S_ystem Color"));
 	gtk_widget_add_accelerator(check11,"clicked",accel,key,GDK_MOD1_MASK,0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check0),ft->gline);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check1),ft->space);
@@ -437,7 +437,7 @@ gboolean property_dialog(FTYPE *ft)
 	if (ft->text!=NULL && ft->ext!=NULL) {
 		check12=gtk_check_button_new_with_label(NULL);
 		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check12)->child),
-										_("ե륿פϢŤ(_A)"));
+													_("_Associate File Type"));
 		gtk_widget_add_accelerator(check12,"clicked",accel,
 														key,GDK_MOD1_MASK,0);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check12),ft->associate);
@@ -470,10 +470,10 @@ gboolean property_dialog(FTYPE *ft)
 					break;
 				}
 			if (label==NULL)
-				label=gtk_label_new(_("ե륿"));
+				label=gtk_label_new(_("Unknow File Type"));
 		} else {
 			/* ե륿פʤ */
-			label=gtk_label_new(_("ե륿פʤ"));
+			label=gtk_label_new(_("Independent File Type"));
 		}
 		gtk_misc_set_alignment(GTK_MISC(label),0,0.5);
 		entry0=entry1=NULL;
@@ -528,19 +528,19 @@ gboolean property_dialog(FTYPE *ft)
 	if (entry0!=NULL && entry1!=NULL) {
 		hbox=gtk_hbox_new(FALSE,0);
 		gtk_box_pack_start(GTK_BOX(hbox),
-									gtk_label_new(_("ʸ")),FALSE,FALSE,0);
+									gtk_label_new(_("Title")),FALSE,FALSE,0);
 		gtk_box_pack_start(GTK_BOX(hbox),entry0,TRUE,TRUE,0);
 		gtk_box_pack_start(GTK_BOX(tbox),hbox,TRUE,TRUE,0);
 		hbox=gtk_hbox_new(FALSE,0);
 		gtk_box_pack_start(GTK_BOX(hbox),
-									gtk_label_new(_("ĥ")),FALSE,FALSE,0);
+								gtk_label_new(_("Extension")),FALSE,FALSE,0);
 		gtk_box_pack_start(GTK_BOX(hbox),entry1,TRUE,TRUE,0);
 		gtk_box_pack_start(GTK_BOX(tbox),hbox,TRUE,TRUE,0);
 	} else {
 		gtk_box_pack_start(GTK_BOX(tbox),label,TRUE,TRUE,0);
 	}
 
-	frame0=gtk_frame_new(_("ɽ"));
+	frame0=gtk_frame_new(_("Display"));
 	hbox=gtk_hbox_new(FALSE,8);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox),8);
 	gtk_box_pack_start(GTK_BOX(hbox),check0,FALSE,FALSE,0);
@@ -548,7 +548,7 @@ gboolean property_dialog(FTYPE *ft)
 	gtk_box_pack_start(GTK_BOX(hbox),check2,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(frame0),hbox);
 
-	frame1=gtk_frame_new(_("ޡ"));
+	frame1=gtk_frame_new(_("Right Margin"));
 	hbox=gtk_hbox_new(FALSE,8);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox),8);
 	gtk_box_pack_start(GTK_BOX(hbox),spin0,TRUE,TRUE,0);
@@ -556,7 +556,7 @@ gboolean property_dialog(FTYPE *ft)
 	gtk_box_pack_start(GTK_BOX(hbox),check4,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(frame1),hbox);
 
-	frame2=gtk_frame_new(_(""));
+	frame2=gtk_frame_new(_("Tab"));
 	hbox=gtk_hbox_new(FALSE,8);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox),8);
 	gtk_box_pack_start(GTK_BOX(hbox),spin1,TRUE,TRUE,0);
@@ -565,7 +565,7 @@ gboolean property_dialog(FTYPE *ft)
 	gtk_box_pack_start(GTK_BOX(hbox),check7,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(frame2),hbox);
 
-	frame3=gtk_frame_new(_("Խ"));
+	frame3=gtk_frame_new(_("Edit"));
 	vbox=gtk_vbox_new(FALSE,8);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
 	gtk_box_pack_start(GTK_BOX(vbox),check8,FALSE,FALSE,0);
@@ -573,7 +573,7 @@ gboolean property_dialog(FTYPE *ft)
 	gtk_box_pack_start(GTK_BOX(vbox),check10,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(frame3),vbox);
 
-	frame4=gtk_frame_new(_(""));
+	frame4=gtk_frame_new(_("Color"));
 	vbox=gtk_vbox_new(FALSE,8);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
 	gtk_box_pack_start(GTK_BOX(vbox),scroll,TRUE,TRUE,0);
