@@ -99,7 +99,7 @@ gint replace_dialog(REPLACE *rp)
 
 	/* ᥤ󥦥ɥ */
 	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
-	gtk_window_set_title(GTK_WINDOW(dialog),_("ִ"));
+	gtk_window_set_title(GTK_WINDOW(dialog),_("Replace"));
 	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
 							GTK_SIGNAL_FUNC(replace_dialog_key_press),NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
@@ -109,12 +109,11 @@ gint replace_dialog(REPLACE *rp)
 	/* ܥ */
 	button0=gtk_button_new_with_label(NULL);
 	button1=gtk_button_new_with_label(NULL);
-	button2=gtk_button_new_with_label(_(""));
+	button2=gtk_button_new_with_label(_("Cancel"));
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button0)->child),
-																_("ִ(_R)"));
+																_("_Replace"));
 	gtk_widget_add_accelerator(button0,"clicked",accel,key,GDK_MOD1_MASK,0);
-	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button1)->child),
-														_("٤ִ(_A)"));
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button1)->child),_("_All"));
 	gtk_widget_add_accelerator(button1,"clicked",accel,key,GDK_MOD1_MASK,0);
 	gtk_signal_connect(GTK_OBJECT(button0),"clicked",
 												replace_dialog_clicked_ok,rp);
@@ -128,7 +127,7 @@ gint replace_dialog(REPLACE *rp)
 	/* åܥ */
 	check=gtk_check_button_new_with_label(NULL);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check)->child),
-											_("ʸ/ʸ̤(_C)"));
+															_("Enable _Case"));
 	gtk_widget_add_accelerator(check,"clicked",accel,key,GDK_MOD1_MASK,0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),rp->ignorecase);
 	/* ܥܥå */
@@ -160,9 +159,9 @@ gint replace_dialog(REPLACE *rp)
 	radio0=gtk_radio_button_new_with_label(NULL,NULL);
 	radio1=gtk_radio_button_new_with_label_from_widget(
 												GTK_RADIO_BUTTON(radio0),NULL);
-	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),_("(_U)"));
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),_("_Up"));
 	gtk_widget_add_accelerator(radio0,"clicked",accel,key,GDK_MOD1_MASK,0);
-	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),_("(_D)"));
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),_("_Down"));
 	gtk_widget_add_accelerator(radio1,"clicked",accel,key,GDK_MOD1_MASK,0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(rp->arrow?radio1:radio0),
 																		TRUE);
@@ -171,22 +170,22 @@ gint replace_dialog(REPLACE *rp)
 	gtk_container_set_border_width(GTK_CONTAINER(tbox),8);
 	hbox=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox),
-								gtk_label_new(_("ʸ")),FALSE,FALSE,0);
+								gtk_label_new(_("Find String")),FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox),combo0,TRUE,TRUE,0);
 	gtk_box_pack_start(GTK_BOX(tbox),hbox,FALSE,FALSE,0);
 	hbox=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox),
-								gtk_label_new(_("ִʸ")),FALSE,FALSE,0);
+							gtk_label_new(_("Replace String")),FALSE,FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox),combo1,TRUE,TRUE,0);
 	gtk_box_pack_start(GTK_BOX(tbox),hbox,FALSE,FALSE,0);
 
-	frame0=gtk_frame_new(_("ץ"));
+	frame0=gtk_frame_new(_("Option"));
 	vbox=gtk_vbox_new(FALSE,8);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
 	gtk_box_pack_start(GTK_BOX(vbox),check,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(frame0),vbox);
 
-	frame1=gtk_frame_new(_("ִ"));
+	frame1=gtk_frame_new(_("Direction"));
 	vbox=gtk_vbox_new(FALSE,8);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
 	gtk_box_pack_start(GTK_BOX(vbox),radio0,FALSE,FALSE,0);
