@@ -556,13 +556,13 @@ gboolean signal_button_press(GtkWidget *widget,
 			break;
 		case 3:/* å */
 			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
-				item_factory_popup,_("<main>/᤹(U)")),ptw->undo!=NULL);
+					item_factory_popup,_("<main>/Undo")),ptw->undo!=NULL);
 			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
-				item_factory_popup,_("<main>/ڤ(T)")),ptw->select.x>=0);
+					item_factory_popup,_("<main>/Cut")),ptw->select.x>=0);
 			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
-				item_factory_popup,_("<main>/ԡ(C)")),ptw->select.x>=0);
+					item_factory_popup,_("<main>/Copy")),ptw->select.x>=0);
 			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
-				item_factory_popup,_("<main>/(L)")),ptw->select.x>=0);
+					item_factory_popup,_("<main>/Delete")),ptw->select.x>=0);
 			gtk_menu_popup(GTK_MENU(
 					gtk_item_factory_get_widget(item_factory_popup,"<main>")),
 								NULL,NULL,NULL,NULL,event->button,event->time);
@@ -1282,13 +1282,13 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 				set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
 										0,ptw->max-1,sy,ptw->top.y);
 			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
-				item_factory_popup,_("<main>/᤹(U)")),ptw->undo!=NULL);
+					item_factory_popup,_("<main>/Undo")),ptw->undo!=NULL);
 			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
-				item_factory_popup,_("<main>/ڤ(T)")),ptw->select.x>=0);
+					item_factory_popup,_("<main>/Cut")),ptw->select.x>=0);
 			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
-				item_factory_popup,_("<main>/ԡ(C)")),ptw->select.x>=0);
+					item_factory_popup,_("<main>/Copy")),ptw->select.x>=0);
 			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
-				item_factory_popup,_("<main>/(L)")),ptw->select.x>=0);
+					item_factory_popup,_("<main>/Delete")),ptw->select.x>=0);
 			gtk_menu_popup(GTK_MENU(
 					gtk_item_factory_get_widget(item_factory_popup,"<main>")),
 											NULL,NULL,NULL,NULL,3,event->time);
@@ -1343,8 +1343,7 @@ void signal_destroy_draw(GtkWidget *widget,TEXTWND *ptw)
 	/* ե̾Ĵ٤ */
 	delete_edit_file(ptw->file);
 	/* ɥ˥塼 */
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,
-													_("<main>/ɥ(W)"));
+	sub_menu=gtk_item_factory_get_widget(item_factory_menu,_("<main>/Window"));
 	gtk_container_remove(GTK_CONTAINER(sub_menu),ptw->menu_item);
 	/* ˥塼 */
 	glist=gtk_container_children(GTK_CONTAINER(notebook));
@@ -1728,8 +1727,7 @@ void signal_destroy_window(GtkWidget *widget,gpointer user_data)
 	GtkWidget *sub_menu;
 
 	memset(hisfile,0,sizeof(gchar *)*10);
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,
-													_("<main>/ե(F)"));
+	sub_menu=gtk_item_factory_get_widget(item_factory_menu,_("<main>/File"));
 	glist=gtk_container_children(GTK_CONTAINER(sub_menu));
 	for (i=0;i<(gint)g_list_length(glist)-MENUFILE-1;i++)
 		hisfile[i]=g_strdup(gtk_object_get_user_data(
