@@ -101,57 +101,57 @@ int main(int argc,char *argv[])
 	GtkStyle *style;
 	GtkWidget *menubar,*toolbar,*text,*handle,*vbox,*sub_menu,*menu_item;
 	GtkItemFactoryEntry menu_items[]={
-{N_("/ե(_F)"),                               NULL,         NULL,            0,"<Branch>"},
-{N_("/ե(F)/(_N)"),                   "<control>N", command_new,     0,"<Item>"},
-{N_("/ե(F)/(_O)..."),                    "<control>O", command_open,    0,"<Item>"},
-{N_("/ե(F)/Ĥ(_C)"),                     "<control>W", command_close,   0,"<Item>"},
-{N_("/ե(F)/¸(_S)"),                 "<control>S", command_save,    0,"<Item>"},
-{N_("/ե(F)/̾Ĥ¸(_A)..."),        NULL,         command_saveas,  0,"<Item>"},
-{N_("/ե(F)/¸Ƥ֤᤹(_R)..."),"<control>R", command_reload,  0,"<Item>"},
-{N_("/ե(F)/Sep1"),                           NULL,         NULL,            0,"<Separator>"},
+{N_("/_File"),                             NULL,         NULL,            0,"<Branch>"},
+{N_("/File/_New"),                         "<control>N", command_new,     0,"<Item>"},
+{N_("/File/_Open..."),                     "<control>O", command_open,    0,"<Item>"},
+{N_("/File/_Close"),                       "<control>W", command_close,   0,"<Item>"},
+{N_("/File/_Save"),                        "<control>S", command_save,    0,"<Item>"},
+{N_("/File/Save _As..."),                  NULL,         command_saveas,  0,"<Item>"},
+{N_("/File/_Reload"),                      "<control>R", command_reload,  0,"<Item>"},
+{N_("/File/Sep1"),                         NULL,         NULL,            0,"<Separator>"},
 #ifdef USE_GDKPIXBUF
-{N_("/ե(F)/(_P)..."),                    "<control>P", command_print,   0,"<Item>"},
-{N_("/ե(F)/Sep2"),                           NULL,         NULL,            0,"<Separator>"},
+{N_("/File/_Print..."),                    "<control>P", command_print,   0,"<Item>"},
+{N_("/File/Sep2"),                         NULL,         NULL,            0,"<Separator>"},
 #endif
-{N_("/ե(F)/ץѥƥ(_I)..."),              "<alt>Return",command_property,0,"<Item>"},
-{N_("/ե(F)/Sep3"),                           NULL,         NULL,            0,"<Separator>"},
-{N_("/ե(F)/λ(_X)"),                       "<control>Q", command_exit,    0,"<Item>"},
-{N_("/Խ(_E)"),                                   NULL,         NULL,            0,"<Branch>"},
-{N_("/Խ(E)/᤹(_U)"),                       "<control>Z", command_undo,    0,"<Item>"},
-{N_("/Խ(E)/ľ(_R)"),                       "F4",         command_redo,    0,"<Item>"},
-{N_("/Խ(E)/Sep1"),                               NULL,         NULL,            0,"<Separator>"},
-{N_("/Խ(E)/ڤ(_T)"),                       "<control>X", command_cut,     0,"<Item>"},
-{N_("/Խ(E)/ԡ(_C)"),                         "<control>C", command_copy,    0,"<Item>"},
-{N_("/Խ(E)/Žդ(_P)"),                       "<control>V", command_paste,   0,"<Item>"},
-{N_("/Խ(E)/(_L)"),                           NULL,         command_delete,  0,"<Item>"},
-{N_("/Խ(E)/Sep2"),                               NULL,         NULL,            0,"<Separator>"},
-{N_("/Խ(E)/ޡǲԤ(_M)"),           NULL,         command_margin,  0,"<Item>"},
-{N_("/Խ(E)/֤򥹥ڡѴ(_B)"),       NULL,         command_tab,     0,"<Item>"},
-{N_("/Խ(E)/Sep3"),                               NULL,         NULL,            0,"<Separator>"},
-{N_("/Խ(E)/ʸ(_W)..."),              NULL,         command_valchr,  0,"<Item>"},
-{N_("/Խ(E)/Ԥذư(_J)..."),                "<control>J", command_jump,    0,"<Item>"},
-{N_("/Խ(E)/Sep4"),                               NULL,         NULL,            0,"<Separator>"},
-{N_("/Խ(E)/٤(_A)"),                     "<control>A", command_all,     0,"<Item>"},
-{N_("/(_S)"),                                   NULL,         NULL,            0,"<Branch>"},
-{N_("/(S)/(_F)..."),                        "<control>F", command_find,    0,"<Item>"},
-{N_("/(S)/򸡺(_N)"),                       "F3",         command_next,    0,"<Item>"},
-{N_("/(S)/դ򸡺(_B)"),                       "<shift>F3",  command_next,    1,"<Item>"},
-{N_("/(S)/ִ(_R)..."),                        "<control>H", command_replace, 0,"<Item>"},
-{N_("/ץ(_O)"),                             NULL,         NULL,            0,"<Branch>"},
-{N_("/ץ(O)/(_C)..."),                  NULL,         conf_dialog,     0,"<Item>"},
-{N_("/ץ(O)/ե륿(_T)..."),        NULL,         format_dialog,   0,"<Item>"},
-{N_("/ɥ(_W)"),                             NULL,         NULL,            0,"<Branch>"},
-{N_("/إ(_H)"),                                 NULL,         NULL,            0,"<Branch>"},
-{N_("/إ(H)/С(_A)..."),            NULL,         version_dialog,  0,"<Item>"}};
+{N_("/File/Propert_ies..."),               "<alt>Return",command_property,0,"<Item>"},
+{N_("/File/Sep3"),                         NULL,         NULL,            0,"<Separator>"},
+{N_("/File/E_xit"),                        "<control>Q", command_exit,    0,"<Item>"},
+{N_("/_Edit"),                             NULL,         NULL,            0,"<Branch>"},
+{N_("/Edit/_Undo"),                        "<control>Z", command_undo,    0,"<Item>"},
+{N_("/Edit/_Redo"),                        "F4",         command_redo,    0,"<Item>"},
+{N_("/Edit/Sep1"),                         NULL,         NULL,            0,"<Separator>"},
+{N_("/Edit/Cu_t"),                         "<control>X", command_cut,     0,"<Item>"},
+{N_("/Edit/_Copy"),                        "<control>C", command_copy,    0,"<Item>"},
+{N_("/Edit/_Paste"),                       "<control>V", command_paste,   0,"<Item>"},
+{N_("/Edit/De_lete"),                      NULL,         command_delete,  0,"<Item>"},
+{N_("/Edit/Sep2"),                         NULL,         NULL,            0,"<Separator>"},
+{N_("/Edit/Return at Right _Margin"),      NULL,         command_margin,  0,"<Item>"},
+{N_("/Edit/Convert Ta_b to Space"),        NULL,         command_tab,     0,"<Item>"},
+{N_("/Edit/Sep3"),                         NULL,         NULL,            0,"<Separator>"},
+{N_("/Edit/_Character by _Value..."),      NULL,         command_valchr,  0,"<Item>"},
+{N_("/Edit/_Jump..."),                     "<control>J", command_jump,    0,"<Item>"},
+{N_("/Edit/Sep4"),                         NULL,         NULL,            0,"<Separator>"},
+{N_("/Edit/_All"),                         "<control>A", command_all,     0,"<Item>"},
+{N_("/_Search"),                           NULL,         NULL,            0,"<Branch>"},
+{N_("/Search/_Find..."),                   "<control>F", command_find,    0,"<Item>"},
+{N_("/Search/_Next"),                      "F3",         command_next,    0,"<Item>"},
+{N_("/Search/_Previous"),                  "<shift>F3",  command_next,    1,"<Item>"},
+{N_("/Search/_Replace..."),                "<control>H", command_replace, 0,"<Item>"},
+{N_("/_Option"),                           NULL,         NULL,            0,"<Branch>"},
+{N_("/Option/_Configuration..."),          NULL,         conf_dialog,     0,"<Item>"},
+{N_("/Option/File _Type..."),              NULL,         format_dialog,   0,"<Item>"},
+{N_("/_Window"),                           NULL,         NULL,            0,"<Branch>"},
+{N_("/_Help"),                             NULL,         NULL,            0,"<Branch>"},
+{N_("/Help/_About..."),                    NULL,         version_dialog,  0,"<Item>"}};
 	GtkItemFactoryEntry popup_items[]={
-{N_("/᤹(_U)"),                               "<control>Z", command_undo,    0,"<Item>"},
-{N_("/Sep1"),                                       NULL,         NULL,            0,"<Separator>"},
-{N_("/ڤ(_T)"),                               "<control>X", command_cut,     0,"<Item>"},
-{N_("/ԡ(_C)"),                                 "<control>C", command_copy,    0,"<Item>"},
-{N_("/Žդ(_P)"),                               "<control>V", command_paste,   0,"<Item>"},
-{N_("/(_L)"),                                   NULL,         command_delete,  0,"<Item>"},
-{N_("/Sep2"),                                       NULL,         NULL,            0,"<Separator>"},
-{N_("/٤(_A)"),                             "<control>A", command_all,     0,"<Item>"}};
+{N_("/_Undo"),                             "<control>Z", command_undo,    0,"<Item>"},
+{"/Sep1",                                  NULL,         NULL,            0,"<Separator>"},
+{N_("/Cu_t"),                              "<control>X", command_cut,     0,"<Item>"},
+{N_("/_Copy"),                             "<control>C", command_copy,    0,"<Item>"},
+{N_("/_Paste"),                            "<control>V", command_paste,   0,"<Item>"},
+{N_("/De_lete"),                           NULL,         command_delete,  0,"<Item>"},
+{"/Sep2",                                  NULL,         NULL,            0,"<Separator>"},
+{N_("/_All"),                              "<control>A", command_all,     0,"<Item>"}};
 	/* Drag&Drop */
 	GtkTargetEntry drag_types[1]={{"text/uri-list",0,0}};
 	/* ޥɥ饤  */
@@ -162,14 +162,14 @@ int main(int argc,char *argv[])
 		const char *doc;
 	};
 	const struct arg_opt arg_opts[]={
-	{"encoding",'c',"CHARSET",     N_("饯󥳡ǥ")},
-	{"history", 'h',"NUM",         N_("ե")},
-	{"line",    'l',"NUM",         N_("ΥåȰ")},
-	{"new",     'n',"ON/OFF",      N_("ե򳫤")},
-	{"size",    's',"WIDTH,HEIGHT",N_("ɥΥ")},
-	{"second",  'x',"ON/OFF",      N_("ɥ򳫤")},
-	{"version", 'v',NULL,          N_("С")},
-	{"help",    '?',NULL,          N_("إ")},
+	{"encoding",'c',"CHARSET",     N_("Character Encoding")},
+	{"history", 'h',"NUM",         N_("History")},
+	{"line",    'l',"NUM",         N_("Caret Position")},
+	{"new",     'n',"ON/OFF",      N_("New File")},
+	{"size",    's',"WIDTH,HEIGHT",N_("Window Size")},
+	{"second",  'x',"ON/OFF",      N_("Open Window")},
+	{"version", 'v',NULL,          N_("About")},
+	{"help",    '?',NULL,          N_("Help")},
 	{NULL,      0,  NULL,          NULL}};
 
 	/*  */
@@ -186,10 +186,10 @@ int main(int argc,char *argv[])
 	/* 쥸ȥ꤫ɤ߽Ф */
 	if ((profile=profile_open(".tmaid"))!=NULL) {
 		if (!profile_get_value(profile,"tmaid","ftnum",
-				(gpointer)&ftnum,sizeof(gint),PROFILE_VALUE_TYPE_INT))
+						(gpointer)&ftnum,sizeof(gint),PROFILE_VALUE_TYPE_INT))
 			ftnum=0;
 		if (!profile_get_value(profile,"tmaid","history",
-				(gpointer)&history,sizeof(gint),PROFILE_VALUE_TYPE_INT))
+					(gpointer)&history,sizeof(gint),PROFILE_VALUE_TYPE_INT))
 			history=4;
 		if (!profile_get_value(profile,"tmaid","newfile",
 				(gpointer)&newfile,sizeof(gboolean),PROFILE_VALUE_TYPE_BOOL))
@@ -198,13 +198,13 @@ int main(int argc,char *argv[])
 				(gpointer)&second,sizeof(gboolean),PROFILE_VALUE_TYPE_BOOL))
 			second=FALSE;
 		if (!profile_get_value(profile,"tmaid","def_width",
-				(gpointer)&def_width,sizeof(gint),PROFILE_VALUE_TYPE_INT))
+					(gpointer)&def_width,sizeof(gint),PROFILE_VALUE_TYPE_INT))
 			def_width=gdk_screen_width()*2/3;
 		if (!profile_get_value(profile,"tmaid","def_height",
-				(gpointer)&def_height,sizeof(gint),PROFILE_VALUE_TYPE_INT))
+					(gpointer)&def_height,sizeof(gint),PROFILE_VALUE_TYPE_INT))
 			def_height=gdk_screen_height()*2/3;
 		if (!profile_get_value(profile,"tmaid","n_pos",
-				(gpointer)&n_pos,sizeof(gint),PROFILE_VALUE_TYPE_INT))
+						(gpointer)&n_pos,sizeof(gint),PROFILE_VALUE_TYPE_INT))
 			n_pos=GTK_POS_TOP;
 		openpath=profile_get_string(profile,"tmaid","openpath");
 		savepath=profile_get_string(profile,"tmaid","savepath");
@@ -223,7 +223,7 @@ int main(int argc,char *argv[])
 		}
 		/*  */
 		if (!profile_get_value(profile,"tmaid","find_arrow",
-								(gpointer)&find_arrow,sizeof(gboolean),
+										(gpointer)&find_arrow,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
 			find_arrow=TRUE;
 		if (!profile_get_value(profile,"tmaid","find_ignorecase",
@@ -243,7 +243,7 @@ int main(int argc,char *argv[])
 		find_num=i;
 		/* ִ */
 		if (!profile_get_value(profile,"tmaid","replace_arrow",
-								(gpointer)&replace_arrow,sizeof(gboolean),
+									(gpointer)&replace_arrow,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
 			replace_arrow=TRUE;
 		if (!profile_get_value(profile,"tmaid","replace_ignorecase",
@@ -273,27 +273,27 @@ int main(int argc,char *argv[])
 		if ((printer.file=profile_get_string(profile,"printer","file"))==NULL)
 			printer.file=g_strdup("tmaid.ps");
 		if (!profile_get_value(profile,"printer","width",
-								(gpointer)&printer.width,sizeof(gint),
+										(gpointer)&printer.width,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT))
 			printer.width=594;
 		if (!profile_get_value(profile,"printer","height",
-								(gpointer)&printer.height,sizeof(gint),
+										(gpointer)&printer.height,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT))
 			printer.height=840;
 		if (!profile_get_value(profile,"printer","left",
-								(gpointer)&printer.left,sizeof(gint),
+										(gpointer)&printer.left,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT))
 			printer.left=20;
 		if (!profile_get_value(profile,"printer","top",
-								(gpointer)&printer.top,sizeof(gint),
+										(gpointer)&printer.top,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT))
 			printer.top=20;
 		if (!profile_get_value(profile,"printer","right",
-								(gpointer)&printer.right,sizeof(gint),
+										(gpointer)&printer.right,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT))
 			printer.right=20;
 		if (!profile_get_value(profile,"printer","bottom",
-								(gpointer)&printer.bottom,sizeof(gint),
+										(gpointer)&printer.bottom,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT))
 			printer.bottom=20;
 #endif
@@ -499,7 +499,7 @@ int main(int argc,char *argv[])
 	if (ftnum<=0) {
 		ftnum=1;
 		ftype=g_malloc(ftnum*sizeof(FTYPE));
-		ftype[0].text=g_strdup(_("٤ƤΥե"));
+		ftype[0].text=g_strdup(_("All Files"));
 		ftype[0].ext=g_strdup("*");
 		ftype[0].margin=80;
 		ftype[0].tab=8;
@@ -609,8 +609,7 @@ int main(int argc,char *argv[])
 	gtk_box_pack_end(GTK_BOX(vbox),text,FALSE,FALSE,0);
 	gtk_container_add(GTK_CONTAINER(window),vbox);
 	/* ե */
-	sub_menu=gtk_item_factory_get_widget(item_factory_menu,
-													_("<main>/ե(F)"));
+	sub_menu=gtk_item_factory_get_widget(item_factory_menu,_("<main>/File"));
 	for (i=0;i<history && hisfile[i]!=NULL;i++) {
 		menu_item=gtk_menu_item_new_with_label(hisfile[i]);
 		gtk_signal_connect(GTK_OBJECT(menu_item),"activate",
@@ -702,19 +701,19 @@ int main(int argc,char *argv[])
 	/* 쥸ȥ˽񤭹 */
 	if ((profile=profile_open(".tmaid"))!=NULL) {
 		profile_set_value(profile,"tmaid","ftnum",
-				(gpointer)&ftnum,sizeof(gint),PROFILE_VALUE_TYPE_INT);
+						(gpointer)&ftnum,sizeof(gint),PROFILE_VALUE_TYPE_INT);
 		profile_set_value(profile,"tmaid","history",
-				(gpointer)&history,sizeof(gint),PROFILE_VALUE_TYPE_INT);
+					(gpointer)&history,sizeof(gint),PROFILE_VALUE_TYPE_INT);
 		profile_set_value(profile,"tmaid","newfile",
 				(gpointer)&newfile,sizeof(gboolean),PROFILE_VALUE_TYPE_BOOL);
 		profile_set_value(profile,"tmaid","second",
 				(gpointer)&second,sizeof(gboolean),PROFILE_VALUE_TYPE_BOOL);
 		profile_set_value(profile,"tmaid","def_width",
-				(gpointer)&def_width,sizeof(gint),PROFILE_VALUE_TYPE_INT);
+					(gpointer)&def_width,sizeof(gint),PROFILE_VALUE_TYPE_INT);
 		profile_set_value(profile,"tmaid","def_height",
-				(gpointer)&def_height,sizeof(gint),PROFILE_VALUE_TYPE_INT);
+					(gpointer)&def_height,sizeof(gint),PROFILE_VALUE_TYPE_INT);
 		profile_set_value(profile,"tmaid","n_pos",
-				(gpointer)&n_pos,sizeof(gint),PROFILE_VALUE_TYPE_INT);
+						(gpointer)&n_pos,sizeof(gint),PROFILE_VALUE_TYPE_INT);
 		if (openpath!=NULL)
 			profile_set_value(profile,"tmaid","openpath",(gpointer)openpath,
 											(strlen(openpath)+1)*sizeof(gchar),
@@ -739,13 +738,13 @@ int main(int argc,char *argv[])
 		}
 		/*  */
 		profile_set_value(profile,"tmaid","find_arrow",
-								(gpointer)&find_arrow,sizeof(gboolean),
+										(gpointer)&find_arrow,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
 		profile_set_value(profile,"tmaid","find_ignorecase",
 								(gpointer)&find_ignorecase,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
 		profile_set_value(profile,"tmaid","find_num",
-				(gpointer)&find_num,sizeof(gint),PROFILE_VALUE_TYPE_INT);
+					(gpointer)&find_num,sizeof(gint),PROFILE_VALUE_TYPE_INT);
 		for (i=0;i<find_num;i++) {
 			key=g_strdup_printf("find%02d",i);
 			profile_set_value(profile,"tmaid",key,(gpointer)find_text[i],
@@ -761,7 +760,7 @@ int main(int argc,char *argv[])
 		}
 		/* ִ */
 		profile_set_value(profile,"tmaid","replace_arrow",
-								(gpointer)&replace_arrow,sizeof(gboolean),
+									(gpointer)&replace_arrow,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
 		profile_set_value(profile,"tmaid","replace_ignorecase",
 								(gpointer)&replace_ignorecase,sizeof(gboolean),
@@ -784,7 +783,7 @@ int main(int argc,char *argv[])
 #ifdef USE_GDKPIXBUF
 		/*  */
 		profile_set_value(profile,"printer","mode",
-								(gpointer)&printer.mode,sizeof(gboolean),
+									(gpointer)&printer.mode,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
 		profile_set_value(profile,"printer","printer",
 									(gpointer)printer.printer,
@@ -794,22 +793,22 @@ int main(int argc,char *argv[])
 										(strlen(printer.file)+1)*sizeof(gchar),
 													PROFILE_VALUE_TYPE_STRING);
 		profile_set_value(profile,"printer","width",
-								(gpointer)&printer.width,sizeof(gint),
+										(gpointer)&printer.width,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT);
 		profile_set_value(profile,"printer","height",
-								(gpointer)&printer.height,sizeof(gint),
+										(gpointer)&printer.height,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT);
 		profile_set_value(profile,"printer","left",
-								(gpointer)&printer.left,sizeof(gint),
+										(gpointer)&printer.left,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT);
 		profile_set_value(profile,"printer","top",
-								(gpointer)&printer.top,sizeof(gint),
+										(gpointer)&printer.top,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT);
 		profile_set_value(profile,"printer","right",
-								(gpointer)&printer.right,sizeof(gint),
+										(gpointer)&printer.right,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT);
 		profile_set_value(profile,"printer","bottom",
-								(gpointer)&printer.bottom,sizeof(gint),
+										(gpointer)&printer.bottom,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT);
 #endif
 		/* ե륿 */
